@@ -356,6 +356,13 @@ impl Cluster {
         let gateway = http
             .gateway()
             .authed()
+            .exec()
+            .await
+            .map_err(|source| ClusterStartError {
+                kind: ClusterStartErrorType::RetrievingGatewayInfo,
+                source: Some(Box::new(source)),
+            })?
+            .model()
             .await
             .map_err(|source| ClusterStartError {
                 kind: ClusterStartErrorType::RetrievingGatewayInfo,
