@@ -286,9 +286,14 @@ impl ShardProcessor {
         let shard_id = config.shard();
         let resumable = config.sequence.is_some() && config.session_id.is_some();
         if !resumable {
+            #[cfg(feature = "tracing")]
             tracing::debug!("shard {:?} is not resumable", shard_id);
+            #[cfg(feature = "tracing")]
             tracing::debug!("shard {:?} queued", shard_id);
+
             config.queue.request(shard_id).await;
+
+            #[cfg(feature = "tracing")]
             tracing::debug!("shard {:?} finished queue", config.shard());
         }
 
@@ -330,7 +335,9 @@ impl ShardProcessor {
         };
 
         if resumable {
+            #[cfg(feature = "tracing")]
             tracing::debug!("resuming shard {:?}", shard_id);
+
             processor.resume().await;
         }
 
@@ -342,6 +349,7 @@ impl ShardProcessor {
             match self.next_payload().await {
                 Ok(v) => v,
                 Err(source) => {
+                    #[cfg(feature = "tracing")]
                     tracing::warn!("{}", source);
 
                     self.emit_disconnected(None, None).await;
@@ -363,6 +371,7 @@ impl ShardProcessor {
             };
 
             if let Err(source) = self.process().await {
+                #[cfg(feature = "tracing")]
                 tracing::warn!(
                     shard_id = self.config.shard()[0],
                     shard_total = self.config.shard()[1],
@@ -371,6 +380,7 @@ impl ShardProcessor {
                 );
 
                 if source.fatal() {
+                    #[cfg(feature = "tracing")]
                     tracing::debug!("error processing event; reconnecting");
                     self.emit_disconnected(None, None).await;
 
@@ -389,7 +399,9 @@ impl ShardProcessor {
                 source: Some(Box::new(source)),
             })?;
 
+            #[cfg(feature = "tracing")]
             tracing::trace!(%json, "Received JSON");
+
             let emitter = self.emitter.clone();
 
             let (op, seq, event_type) =
@@ -403,8 +415,9 @@ impl ShardProcessor {
                     // should be a good trade-off either way.
                     (op, seq, event_type.map(ToOwned::to_owned))
                 } else {
+                    #[cfg(feature = "tracing")]
                     tracing::warn!(
-                        json = ?self.compression.buffer_slice_ref(),
+                        json = ?self.compression.buffer_slice_mut(),
                         shard_id = self.config.shard()[0],
                         shard_total = self.config.shard()[1],
                         seq = self.session.seq(),
@@ -572,8 +585,10 @@ impl ShardProcessor {
             self.resume().await;
         }
 
-        if let Err(err) = self.session.heartbeat() {
-            tracing::warn!("error sending heartbeat; reconnecting: {}", err);
+        if let Err(_source) = self.session.heartbeat() {
+            #[cfg(feature = "tracing")]
+            tracing::warn!("error sending heartbeat; reconnecting: {}", _source);
+
             self.emit_disconnected(None, None).await;
 
             self.reconnect().await;
@@ -584,13 +599,17 @@ impl ShardProcessor {
         #[cfg(feature = "metrics")]
         metrics::counter!("GatewayEvent", 1, "GatewayEvent" => "Hello");
 
+        #[cfg(feature = "tracing")]
         tracing::debug!("got hello with interval {}", interval);
 
         if self.session.stage() == Stage::Resuming && self.resume.is_some() {
             // Safe to unwrap so here as we have just checked that
             // it is some.
             let (seq, id) = self.resume.take().unwrap();
+
+            #[cfg(feature = "tracing")]
             tracing::debug!("resuming with sequence {}, session id {}", seq, id);
+
             let payload = Resume::new(seq, id.clone().into_string(), self.config.token());
 
             // Set id so it is correct for next resume.
@@ -629,13 +648,17 @@ impl ShardProcessor {
             #[cfg(feature = "metrics")]
             metrics::counter!("GatewayEvent", 1, "GatewayEvent" => "InvalidateSessionTrue");
 
+            #[cfg(feature = "tracing")]
             tracing::debug!("got request to resume the session");
+
             self.resume().await;
         } else {
             #[cfg(feature = "metrics")]
             metrics::counter!("GatewayEvent", 1, "GatewayEvent" => "InvalidateSessionFalse");
 
+            #[cfg(feature = "tracing")]
             tracing::debug!("got request to invalidate the session and reconnect");
+
             self.reconnect().await;
         }
     }
@@ -644,7 +667,9 @@ impl ShardProcessor {
         #[cfg(feature = "metrics")]
         metrics::counter!("GatewayEvent", 1, "GatewayEvent" => "Reconnect");
 
+        #[cfg(feature = "tracing")]
         tracing::debug!("got request to reconnect");
+
         let frame = CloseFrame {
             code: CloseCode::Restart,
             reason: Cow::Borrowed("Reconnecting"),
@@ -664,6 +689,7 @@ impl ShardProcessor {
 
     pub async fn send(&mut self, payload: impl Serialize) -> Result<(), SessionSendError> {
         if let Err(source) = self.session.send(payload) {
+            #[cfg(feature = "tracing")]
             tracing::warn!("sending message failed: {:?}", source);
 
             if matches!(source.kind(), SessionSendErrorType::Sending { .. }) {
@@ -765,6 +791,7 @@ impl ShardProcessor {
         &mut self,
         close_frame: Option<&CloseFrame<'_>>,
     ) -> Result<(), ReceivingEventError> {
+        #[cfg(feature = "tracing")]
         tracing::info!("got close code: {:?}", close_frame);
 
         self.emit_disconnected(
@@ -839,6 +866,7 @@ impl ShardProcessor {
                 source: Some(Box::new(source)),
             })?;
 
+        #[cfg(feature = "tracing")]
         tracing::debug!("Shook hands with remote");
 
         Ok(stream)
@@ -867,17 +895,20 @@ impl ShardProcessor {
 
     /// Perform a full reconnect to the gateway, instantiating a new session.
     async fn reconnect(&mut self) {
+        #[cfg(feature = "tracing")]
         tracing::info!("reconnection started");
 
         let mut wait = Duration::from_secs(1);
 
         loop {
+            #[cfg(feature = "tracing")]
             tracing::debug!(
                 shard_id = self.config.shard()[0],
                 shard_total = self.config.shard()[1],
                 wait_in_seconds = wait.as_secs(),
                 "waiting before attempting a reconnect",
             );
+
             tokio::time::sleep(wait).await;
 
             // Await allowance when doing a full reconnect.
@@ -889,8 +920,9 @@ impl ShardProcessor {
 
             let stream = match Self::connect(&self.url).await {
                 Ok(s) => s,
-                Err(why) => {
-                    tracing::warn!("reconnecting failed: {:?}", why);
+                Err(_source) => {
+                    #[cfg(feature = "tracing")]
+                    tracing::warn!("reconnecting failed: {:?}", _source);
 
                     if wait < Duration::from_secs(128) {
                         wait *= 2;
@@ -914,7 +946,9 @@ impl ShardProcessor {
     /// Resume a session if possible, defaulting to instantiating a new
     /// connection.
     async fn resume(&mut self) {
+        #[cfg(feature = "tracing")]
         tracing::info!("resuming shard {:?}", self.config.shard());
+
         self.session.set_stage(Stage::Resuming);
         self.session.stop_heartbeater();
 
@@ -923,20 +957,23 @@ impl ShardProcessor {
         let id = if let Some(id) = self.session.id() {
             id
         } else {
+            #[cfg(feature = "tracing")]
             tracing::info!("session id unavailable, reconnecting");
+
             self.reconnect().await;
             return;
         };
 
         self.resume = Some((seq, id));
 
-        if let Err(why) = self.try_resume().await {
+        if let Err(_source) = self.try_resume().await {
+            #[cfg(feature = "tracing")]
             tracing::warn!(
                 seq = seq,
                 session_id = ?self.session.id(),
                 shard_id = self.config.shard()[0],
                 "failed to resume session: {:?}",
-                why,
+                _source,
             );
 
             self.reconnect().await;
@@ -969,8 +1006,9 @@ impl ShardProcessor {
         self.rx = rx;
         self.session = Arc::new(Session::new(tx));
 
-        if let Err(why) = self.wtx.send(Arc::clone(&self.session)) {
-            tracing::error!("failed to broadcast new session: {:?}", why);
+        if let Err(_source) = self.wtx.send(Arc::clone(&self.session)) {
+            #[cfg(feature = "tracing")]
+            tracing::error!("failed to broadcast new session: {:?}", _source);
         }
 
         self.session.set_stage(stage);
